/*
 * libtota
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *	 http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdarg.h>
#include <fcntl.h>

#include "SS_ImageUpdate.h"
#include "SS_Engine_Errors.h"
#include "SS_Common.h"

#include "ua_types.h"
#include "fota_tar.h"
#include "fota_common.h"

void SS_Progress(void *pbUserData, SS_UINT32 uPercent)
{
	LOG("Progress before\n");
	LOGL(LOG_SSENGINE, "Progress.. (%u %%)\n", uPercent);
	LOG("Progress after:\n");
	((ua_data_t *) pbUserData)->ui_progress(pbUserData, uPercent);
}

/* Prints a string like the C printf() function */
SS_UINT32 SS_Trace(const char *aFormat, ...)
{
#if 0
	LOGL(LOG_SSENGINE, aFormat);
#else
	char temp[4096];
	va_list list;

	va_start(list, aFormat);
	vsnprintf(temp, sizeof(temp), aFormat, list);
	va_end(list);

	LOGL(LOG_SSENGINE, "%s", temp);
#endif
	return S_SS_SUCCESS;
}

long SS_FSTrace(const unsigned short *aFormat, ...)
{
	va_list list;

	va_start(list, aFormat);
	vprintf((const char *)aFormat, list);
	va_end(list);

	return S_SS_SUCCESS;
}

long SS_ResetTimerA(void)
{
	//LOG("%s \n", __func__);

	return S_SS_SUCCESS;
}

long SS_GetDelta(void *pbUserData, unsigned char *pbBuffer, SS_UINT32 dwStartAddressOffset, SS_UINT32 dwSize)
{
	int ret = S_SS_SUCCESS;
	int readCount = 0;
	FILE *fp;
	long itemOffset = 0;

	ua_data_t *ua_data = (ua_data_t *) pbUserData;
	ua_part_info_t *ua_partition = ua_data->parti_info;
	ua_update_data_t *ua_update_data = ua_data->update_data;

	LOGL(LOG_SSENGINE, "SS_GetDelta offset 0x%x(%u), size 0x%x(%u)\n",
		 dwStartAddressOffset, dwStartAddressOffset, dwSize, dwSize);

	itemOffset = tar_get_item_offset(ua_update_data->ua_delta_path, ua_partition->ua_subject_name);
	if (itemOffset < 0)
		return E_SS_OPENFILE_ONLYR;

	fp = fopen(ua_update_data->ua_delta_path, "r");
	if (!fp) {
		LOGL(LOG_SSENGINE, "open file %s failed.\n", ua_update_data->ua_delta_path);
		return E_SS_OPENFILE_ONLYR;
	}

	if (fseek(fp, itemOffset + dwStartAddressOffset, 0) == -1)
		ret = E_SS_READ_ERROR;
	else {
		readCount = fread(pbBuffer, 1, dwSize, fp);
		if (readCount != dwSize) {
			LOGL(LOG_SSENGINE, "error in read size\n");
			ret = E_SS_READ_ERROR;
		}
	}
	fclose(fp);

	return ret;
}
