/*
 * libtota
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
	SS_Engine Errors

	0xAxx Series define INPUT/UA Errors

	0xBxx Series define Delta Errors

	0xCxx Series define System Errors

	0xDxx Series define Engine Errors

	0xExx Series define any Other Errors

*/

#ifndef __SS_Engine_ERRORS__
#define __SS_Engine_ERRORS__

#define  S_SS_SUCCESS							(0)     /*! Success Code */
#define  E_SS_FAILURE							(1)     /*! Failure Code */

/* INPUT Processing errors */

/* invocation errors */
#define E_SS_BAD_PARAMS							(0xA00)          /**< error in a run parameter */
#define E_SS_FSINVALIDNODEPARAMS					(0xA01) /* Failed to Parse the Params to verify NODE */
#define E_SS_FSBADNODES							(0xA02) /* Failed to verify NODE for FS */
#define E_SS_FSBADDELTA							(0xA03) /* Delta File does NOT contain required information on FS */
#define E_SS_FSBADATTRIBUTES						(0xA04) /* Failed to parse attribute data */
#define E_SS_FSFAILEDTOOPENPATCHINFO					(0xA05) /*Failed to open patch list file having details of PATCH info */
#define E_SS_FSFAILEDTOPARSEDELTACNT					(0xA06) /* Failed to parse the PATCH count information */
#define E_SS_FSFAILEDTOPARSEDELTAINFO					(0xA07) /* Failed to parse the Delta patch information */

/* update package errors */
#define  E_SS_PKG_TOO_LONG						(0xA08) /**< expected length error    */
#define  E_SS_PKG_CORRUPTED						(0xA09) /**< structural error         */
#define  E_SS_SOURCE_CORRUPTED						(0xA10) /**< signature error          */

/*Delta Errors*/

#define E_SS_FSBADPATCH							(0xB00) /*File Patch Does NOT match the signature */
#define E_SS_FSSHA_MISMATCH						(0xB01) /*Could NOT produce expected Target SHA for file */
#define E_SS_IMGBADDELTA						(0xB02) /* Failed to parse attribute data */
#define E_SS_IMGBADPATCH						(0xB03) /*Image Patch Does NOT match the signature */
#define E_SS_IMGSHA_MISMATCH						(0xB04) /*Could NOT produce expected Target SHA for Image */
#define E_SS_SHAPRASE_FAILED						(0xB05) /*Could NOT Parse SHA */

/* SYSTEM errors */

/* Resources errors */
#define  E_SS_NOT_ENOUGH_RAM						(0xC00) /**< given RAM is not enough  */
#define  E_SS_BAD_RAM							(0xC01) /**< does not behave as RAM   */
#define  E_SS_MALLOC_ERROR						(0xC02) /**< memory allocation failure */

/* Image update Error codes */
#define  E_SS_WRITE_ERROR						(0xC03) /**< flash writing failure    */
#define  E_SS_ERASE_ERROR						(0xC04) /**< flash erasing failure    */
#define  E_SS_READ_ERROR						(0xC05) /**< flash reading failure    */

/*File System Error codes */
#define  E_SS_OPENFILE_ONLYR						(0xC06)         /**< file does not exist      */
#define  E_SS_OPENFILE_WRITE						(0xC07)         /**< RO or no access rights   */
#define  E_SS_DELETEFILE_NOFILE						(0xC08) /**< file does not exist      */
#define  E_SS_DELETEFILE						(0xC09) /**< no access rights         */
#define  E_SS_RESIZEFILE						(0xC10) /**< cannot resize file       */
#define  E_SS_READFILE_SIZE						(0xC11) /**< cannot read specified size*/
#define  E_SS_CLOSEFILE_ERROR						(0xC12) /**< cannot close file handle */
#define  E_SS_FAILED_CREATING_SYMBOLIC_LINK				(0xC13)         /**< Failed creating symbolic link */
#define  E_SS_CANNOT_CREATE_DIRECTORY					(0xC14)         /**< Failed creating directory */
#define  E_SS_FSMEMORYERROR						(0xC15) /* Failed to allocate Memory */
#define  E_SS_FILENAMELENERROR						(0xC16) /* Failed to serve filename length */

/*Engine errors */

#define E_SS_NOT_ENOUGH_RAM_FOR_OPERATION2				(0xD00) /**< There is not enough RAM to run with operation=2 (Dry update) */
#define E_SS_DELTA_FILE_TOO_LONG					(0xD01) /**< Delta file too long - curropted */
#define E_SS_ERROR_IN_DELETES_SIG					(0xD02) /**< Mismatch between deletes sig and delta deletes buffers signature */
#define E_SS_DELTA_IS_CORRUPT						(0xD03) /**< Delta file is corrupt: signature mismatch between delta header signature and calculated signature */
#define E_SS_SOURCE_FILE_SIG_MISMATCH					(0xD04) /**< File signature does not match signature */
#define E_SS_TARGET_SIG_MISMATCH					(0xD05) /**< Signature for the target buffer does not match the one stored in the delta file */
#define E_SS_INVALID_BACKUP						(0xD06) /**< Too many dirty buffers */
#define E_SS_UPI_VERSION_MISMATCH					(0xD07) /**< UPI version mismatch between UPI and delta */
#define E_SS_PARTITION_NAME_NOT_FOUND					(0xD08) /**< Partition name is different in delta and in UPI data */
#define E_SS_NO_SPACE_LEFT						(0xD09) /**< There is not enough flash to update or install the files */
#define E_SS_INVALID_DP_HEADER						(0xD10)  /**< Deployment Package header is invalid */
#define E_SS_INVALID_DP_WRONG_SIGNATURE					(0xD11)  /**< Deployment Package signature is invalid */
#define E_SS_FSFAILEDTOBACKUPPATCHINFO					(0xD12) /* Failed to create backup file to write Delta patch info data */
#define E_SS_FSUPDATEFAILED						(0xD13) /*FS Failed during UPGRADE */
#define E_SS_FSSRCBACKUPFAILED						(0xD14) /*Failed to backup FS */
#define E_SS_FSSRCCURRUPTED						(0xD15) /*Could NOT update FS as SRC seems to be corrupted */
#define E_SS_IMGUPDATEFAILED						(0xD16) /*IMG Failed during UPGRADE */
#define E_SS_IMGSRCBACKUPFAILED						(0xD17) /*Failed to backup IMG */
#define E_SS_IMGRECOVERYWRITEFAILED					(0xD18) /*Failed to write patched Recovery IMG */
#define E_SS_IMGSRCCURRUPTED						(0xD19) /*Could NOT update IMG as SRC seems to be corrupted */
#define E_SS_IMGFLASHWRITEFAIL						(0xD20) /*Failed to write Patched IMG data to flash */
#define E_SS_PATCHFILE_DEL_ERROR					(0xD21) /*Failed to Clear/Del Patched SRC file */

#endif
